@@ -6,6 +6,9 @@ use strict;
 use Net::Amazon;
 use Net::Amazon::Request::Blended;
 
+use Log::Log4perl qw(:easy);
+#Log::Log4perl->easy_init($DEBUG);
+
 my $ua = Net::Amazon->new(token => 'AMAZON_TOKEN');
 my $response = $ua->search(blended => ($ARGV[0] || "Perl"));
 my @properties = $response->properties();
